@@ -62,13 +62,10 @@ ConfigureOptionsDialog::ConfigureOptionsDialog(QWidget* parent, const OperationS
     item = addPage(&fileSystemColorsPageWidget(), xi18nc("@title:tab", "File System Colors"), QString(), i18n("File System Color Settings"));
     item->setIcon(QIcon::fromTheme(QStringLiteral("format-fill-color")).pixmap(IconSize(KIconLoader::Desktop)));
 
-    if (QCoreApplication::arguments().contains(QLatin1String("--advconfig"))) {
-        item = addPage(&advancedPageWidget(), xi18nc("@title:tab advanced application settings", "Advanced"), QString(), i18n("Advanced Settings"));
-        item->setIcon(QIcon::fromTheme(QStringLiteral("configure")).pixmap(IconSize(KIconLoader::Desktop)));
+    item = addPage(&advancedPageWidget(), xi18nc("@title:tab advanced application settings", "Advanced"), QString(), i18n("Advanced Settings"));
+    item->setIcon(QIcon::fromTheme(QStringLiteral("configure")).pixmap(IconSize(KIconLoader::Desktop)));
 
-        connect(&advancedPageWidget().comboBackend(), qOverload<int>(&QComboBox::activated), this, &ConfigureOptionsDialog::onComboDefaultFileSystemActivated);
-    } else
-        advancedPageWidget().setVisible(false);
+    connect(&advancedPageWidget().comboBackend(), qOverload<int>(&QComboBox::activated), this, &ConfigureOptionsDialog::onComboDefaultFileSystemActivated);
 
     KConfigGroup kcg(KSharedConfig::openConfig(), "configureOptionsDialogs");
     restoreGeometry(kcg.readEntry<QByteArray>("Geometry", QByteArray()));
@@ -87,8 +84,8 @@ void ConfigureOptionsDialog::updateSettings()
 
     bool changed = false;
 
-    if (generalPageWidget().defaultFileSystem() != Config::defaultFileSystem()) {
-        Config::setDefaultFileSystem(generalPageWidget().defaultFileSystem());
+    if (generalPageWidget().defaultFileSystem() != static_cast<FileSystem::Type>(Config::defaultFileSystem())) {
+        Config::setDefaultFileSystem(static_cast<int>(generalPageWidget().defaultFileSystem()));
         changed = true;
     }
 
@@ -112,7 +109,7 @@ bool ConfigureOptionsDialog::hasChanged()
     bool result = KConfigDialog::hasChanged();
 
     KConfigSkeletonItem* kcItem = Config::self()->findItem(QStringLiteral("defaultFileSystem"));
-    result = result || !kcItem->isEqual(generalPageWidget().defaultFileSystem());
+    result = result || !kcItem->isEqual(static_cast<int>(generalPageWidget().defaultFileSystem()));
     result = result || (generalPageWidget().kcfg_shredSource->checkedId() != Config::shredSource());
 
     if (advancedPageWidget().isVisible()) {
