@@ -19,10 +19,14 @@
 #include "gui/createvolumegroupdialog.h"
 #include "gui/volumegroupwidget.h"
 
+#include <core/device.h>
 #include <core/lvmdevice.h>
+#include <core/partitiontable.h>
 
 #include <fs/lvm2_pv.h>
 
+#include <ops/deleteoperation.h>
+
 #include <util/capacity.h>
 #include <util/helpers.h>
 
@@ -32,10 +36,11 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 
-CreateVolumeGroupDialog::CreateVolumeGroupDialog(QWidget* parent, QString& vgName, QVector<const Partition*>& partList, qint32& peSize, QList<Device*> devices)
+CreateVolumeGroupDialog::CreateVolumeGroupDialog(QWidget* parent, QString& vgName, QVector<const Partition*>& partList, qint32& peSize, QList<Device*> devices, QList<Operation*> pendingOps)
     : VolumeGroupDialog(parent, vgName, partList)
     , m_PESize(peSize)
     , m_Devices(devices)
+    , m_PendingOps(pendingOps)
 {
     setWindowTitle(xi18nc("@title:window", "Create new Volume Group"));
 
@@ -52,9 +57,49 @@ CreateVolumeGroupDialog::CreateVolumeGroupDialog(QWidget* parent, QString& vgNam
 
 void CreateVolumeGroupDialog::setupDialog()
 {
-    for (const auto &p : qAsConst(LVM::pvList))
+    for (const auto &p : qAsConst(LVM::pvList::list())) {
+        bool toBeDeleted = false;
+
+        // Ignore partitions that are going to be deleted
+        for (const auto &o : qAsConst(m_PendingOps)) {
+            if (dynamic_cast<DeleteOperation *>(o) && o->targets(*p.partition())) {
+                toBeDeleted = true;
+                break;
+            }
+        }
+
+        if (toBeDeleted)
+            continue;
+
         if (!p.isLuks() && p.vgName() == QString() && !LvmDevice::s_DirtyPVs.contains(p.partition()))
             dialogWidget().listPV().addPartition(*p.partition(), false);
+    }
+
+    for (const Device *d : qAsConst(m_Devices)) {
+        if (d->partitionTable() != nullptr) {
+            for (const Partition *p : qAsConst(d->partitionTable()->children())) {
+                // Looking if there is another VG creation that contains this partition
+                if (LvmDevice::s_DirtyPVs.contains(p))
+                    continue;
+
+                // Including new LVM PVs (that are currently in OperationStack and that aren't at other VG creation)
+                if (p->state() == Partition::State::New) {
+                    if (p->fileSystem().type() == FileSystem::Type::Lvm2_PV)
+                        dialogWidget().listPV().addPartition(*p, false);
+                    else if (p->fileSystem().type() == FileSystem::Type::Luks || p->fileSystem().type() == FileSystem::Type::Luks2) {
+                        FileSystem *fs = static_cast<const FS::luks *>(&p->fileSystem())->innerFS();
+
+                        if (fs->type() == FileSystem::Type::Lvm2_PV)
+                            dialogWidget().listPV().addPartition(*p, false);
+                    }
+                }
+            }
+        }
+    }
+
+    for (const Partition *p : qAsConst(LvmDevice::s_OrphanPVs))
+        if (!LvmDevice::s_DirtyPVs.contains(p))
+            dialogWidget().listPV().addPartition(*p, false);
 }
 
 void CreateVolumeGroupDialog::setupConnections()
@@ -76,6 +121,14 @@ void  CreateVolumeGroupDialog::accept()
     QDialog::accept();
 }
 
+void CreateVolumeGroupDialog::updateOkButtonStatus()
+{
+    VolumeGroupDialog::updateOkButtonStatus();
+
+    if (okButton->isEnabled())
+        okButton->setEnabled(!dialogWidget().listPV().checkedItems().empty());
+}
+
 void CreateVolumeGroupDialog::onVGNameChanged(const QString& vgName)
 {
     for (const auto &d : m_Devices) {
